@@ -88,7 +88,6 @@ public class StatisticTools extends AbstractJMXTools {
     private static final char OPT_STATS_SHORT = 'x';
     private static final String OPT_STATS_LONG = "xchangestats";
 
-    private static final char OPT_TPSTATS_SHORT = 'p';
     private static final String OPT_TPSTATS_LONG = "threadpoolstats";
 
     private static final char OPT_RUNTIME_STATS_SHORT = 'r';
@@ -125,6 +124,9 @@ public class StatisticTools extends AbstractJMXTools {
     private static final char OPT_DOCUMENTCONVERTER_STATS_SHORT = 'y';
     private static final String OPT_DOCUMENTCONVERTER_STATS_LONG = "documentconverterstats";
 
+    private static final char OPT_IMAGECONVERTER_STATS_SHORT = 'I';
+    private static final String OPT_IMAGECONVERTER_STATS_LONG = "imageconverterstats";
+
     private static final char OPT_OFFICE_STATS_SHORT = 'f';
     private static final String OPT_OFFICE_STATS_LONG = "officestats";
 
@@ -169,6 +171,7 @@ public class StatisticTools extends AbstractJMXTools {
     private CLIOption pnsStats = null;
     private CLIOption webSocketStats = null;
     private CLIOption documentconverterstats = null;
+    private CLIOption imageconverterstats = null;
     private CLIOption officestats = null;
     private CLIOption eventadminstats = null;
     private CLIOption generalstats = null;
@@ -299,6 +302,10 @@ public class StatisticTools extends AbstractJMXTools {
             System.out.print(showDocumentConverterData(mbc));
             count++;
         }
+        if (null != parser.getOptionValue(this.imageconverterstats) && 0 == count) {
+            System.out.print(showImageConverterData(mbc));
+            count++;
+        }
         if (null != parser.getOptionValue(this.officestats) && 0 == count) {
             System.out.print(showOfficeData(mbc));
             count++;
@@ -464,13 +471,11 @@ public class StatisticTools extends AbstractJMXTools {
             "shows Open-Xchange stats",
             false,
             NeededQuadState.notneeded);
-        this.threadpoolstats = setShortLongOpt(
-            parser,
-            OPT_TPSTATS_SHORT,
+        this.threadpoolstats = setLongOpt(parser,
             OPT_TPSTATS_LONG,
             "shows OX-Server threadpool stats",
             false,
-            NeededQuadState.notneeded);
+            false);
         this.runtimestats = setShortLongOpt(
             parser,
             OPT_RUNTIME_STATS_SHORT,
@@ -566,6 +571,13 @@ public class StatisticTools extends AbstractJMXTools {
             "shows the documentconverter stats",
             false,
             NeededQuadState.notneeded);
+        this.imageconverterstats = setShortLongOpt(
+            parser,
+            OPT_IMAGECONVERTER_STATS_SHORT,
+            OPT_IMAGECONVERTER_STATS_LONG,
+            "shows the imageconverter stats",
+            false,
+            NeededQuadState.notneeded);
         this.officestats = setShortLongOpt(
             parser,
             OPT_OFFICE_STATS_SHORT,
@@ -820,6 +832,10 @@ public class StatisticTools extends AbstractJMXTools {
         return getStats(mbeanServerConnection, "com.openexchange.documentconverter:name=DocumentConverterInformation").toString();
     }
 
+    static String showImageConverterData(final MBeanServerConnection mbeanServerConnection) throws InstanceNotFoundException, AttributeNotFoundException, IntrospectionException, MBeanException, ReflectionException, IOException, MalformedObjectNameException, NullPointerException {
+        return getStats(mbeanServerConnection, "com.openexchange.imageconverter:name=ImageConverterMonitoring").toString();
+    }
+
     static String showOfficeData(final MBeanServerConnection mbeanServerConnection) throws InstanceNotFoundException, AttributeNotFoundException, IntrospectionException, MBeanException, ReflectionException, IOException, MalformedObjectNameException, NullPointerException {
         return getStats(mbeanServerConnection, "com.openexchange.office:name=OfficeMonitoring").toString();
     }
