@@ -1,3 +1,52 @@
+/*
+ *
+ *    OPEN-XCHANGE legal information
+ *
+ *    All intellectual property rights in the Software are protected by
+ *    international copyright laws.
+ *
+ *
+ *    In some countries OX, OX Open-Xchange, open xchange and OXtender
+ *    as well as the corresponding Logos OX Open-Xchange and OX are registered
+ *    trademarks of the OX Software GmbH group of companies.
+ *    The use of the Logos is not covered by the GNU General Public License.
+ *    Instead, you are allowed to use these Logos according to the terms and
+ *    conditions of the Creative Commons License, Version 2.5, Attribution,
+ *    Non-commercial, ShareAlike, and the interpretation of the term
+ *    Non-commercial applicable to the aforementioned license is published
+ *    on the web site http://www.open-xchange.com/EN/legal/index.html.
+ *
+ *    Please make sure that third-party modules and libraries are used
+ *    according to their respective licenses.
+ *
+ *    Any modifications to this package must retain all copyright notices
+ *    of the original copyright holder(s) for the original code used.
+ *
+ *    After any such modifications, the original and derivative code shall remain
+ *    under the copyright of the copyright holder(s) and/or original author(s)per
+ *    the Attribution and Assignment Agreement that can be located at
+ *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
+ *    given Attribution for the derivative code and a license granting use.
+ *
+ *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Mail: info@open-xchange.com
+ *
+ *
+ *     This program is free software; you can redistribute it and/or modify it
+ *     under the terms of the GNU General Public License, Version 2 as published
+ *     by the Free Software Foundation.
+ *
+ *     This program is distributed in the hope that it will be useful, but
+ *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+ *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
+ *     for more details.
+ *
+ *     You should have received a copy of the GNU General Public License along
+ *     with this program; if not, write to the Free Software Foundation, Inc., 59
+ *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ *
+ */
+
 package com.openexchange.admin.diff.file.type;
 
 import java.util.List;
@@ -26,6 +75,7 @@ import com.openexchange.test.mock.MockUtils;
  * @author <a href="mailto:martin.schneider@open-xchange.com">Martin Schneider</a>
  * @since 7.6.1
  */
+@SuppressWarnings("unchecked")
 public class ConfFileHandlerTest {
 
     private ConfigurationFile configurationFile = null;
@@ -45,8 +95,8 @@ public class ConfFileHandlerTest {
 
     }
 
-     @Test
-     public void testAddConfigurationFile_noConfigurationFile_fileAdded() {
+    @Test
+    public void testAddConfigurationFile_noConfigurationFile_fileAdded() {
         String fileName = "aaaa.dfdsf";
         String content = "content";
         configurationFile = new ConfigurationFile(fileName, "/opt/open-xchange/bundles", "/jar!/conf", content, false);
@@ -61,8 +111,8 @@ public class ConfFileHandlerTest {
         Assert.assertEquals(content, stringContent);
     }
 
-     @Test
-     public void testAddConfigurationFile_ccfConfigurationFile_fileAdded() {
+    @Test
+    public void testAddConfigurationFile_ccfConfigurationFile_fileAdded() {
         String fileName = "aaaa." + ConfigurationFileTypes.CCF.getFileExtension();
         String content = "content";
 
@@ -79,8 +129,8 @@ public class ConfFileHandlerTest {
 
     }
 
-     @Test
-     public void testAddConfigurationFile_cnfConfigurationFile_fileAdded() {
+    @Test
+    public void testAddConfigurationFile_cnfConfigurationFile_fileAdded() {
         String fileName = "aaaa." + ConfigurationFileTypes.CNF.getFileExtension();
         String content = "content";
 
@@ -96,8 +146,8 @@ public class ConfFileHandlerTest {
         Assert.assertEquals(content, stringContent);
     }
 
-     @Test
-     public void testAddConfigurationFile_confConfigurationFile_fileAdded() {
+    @Test
+    public void testAddConfigurationFile_confConfigurationFile_fileAdded() {
         String fileName = "aaaa." + ConfigurationFileTypes.CONF.getFileExtension();
         String content = "content";
 
@@ -113,8 +163,8 @@ public class ConfFileHandlerTest {
         Assert.assertEquals(content, stringContent);
     }
 
-     @Test
-     public void testAddConfigurationFile_inConfigurationFile_fileAdded() {
+    @Test
+    public void testAddConfigurationFile_inConfigurationFile_fileAdded() {
         String fileName = "aaaa." + ConfigurationFileTypes.PROPERTY.getFileExtension() + "." + ConfigurationFileTypes.IN.getFileExtension();
         String content = "content";
 
@@ -130,8 +180,8 @@ public class ConfFileHandlerTest {
         Assert.assertEquals(content, stringContent);
     }
 
-     @Test
-     public void testAddConfigurationFile_noExtensionConfigurationFile_fileAdded() {
+    @Test
+    public void testAddConfigurationFile_noExtensionConfigurationFile_fileAdded() {
         String fileName = "aaaa." + ConfigurationFileTypes.NO_EXTENSION.getFileExtension();
         String content = "content";
 
@@ -147,8 +197,8 @@ public class ConfFileHandlerTest {
         Assert.assertEquals(content, stringContent);
     }
 
-     @Test
-     public void testAddConfigurationFile_perfmapConfigurationFile_fileAdded() {
+    @Test
+    public void testAddConfigurationFile_perfmapConfigurationFile_fileAdded() {
         String fileName = "aaaa." + ConfigurationFileTypes.PERFMAP.getFileExtension();
         String content = "content";
 
@@ -164,8 +214,8 @@ public class ConfFileHandlerTest {
         Assert.assertEquals(content, stringContent);
     }
 
-     @Test
-     public void testAddConfigurationFile_propertyConfigurationFile_fileAdded() {
+    @Test
+    public void testAddConfigurationFile_propertyConfigurationFile_fileAdded() {
         String fileName = "aaaa." + ConfigurationFileTypes.PROPERTY.getFileExtension();
         String content = "content";
 
@@ -181,8 +231,8 @@ public class ConfFileHandlerTest {
         Assert.assertEquals(content, stringContent);
     }
 
-     @Test
-     public void testAddConfigurationFile_shConfigurationFile_fileAdded() {
+    @Test
+    public void testAddConfigurationFile_shConfigurationFile_fileAdded() {
         String fileName = "aaaa." + ConfigurationFileTypes.SH.getFileExtension();
         String content = "content";
 
@@ -198,8 +248,8 @@ public class ConfFileHandlerTest {
         Assert.assertEquals(content, stringContent);
     }
 
-     @Test
-     public void testAddConfigurationFile_typesConfigurationFile_fileAdded() {
+    @Test
+    public void testAddConfigurationFile_typesConfigurationFile_fileAdded() {
         String fileName = "aaaa." + ConfigurationFileTypes.TYPES.getFileExtension();
         String content = "content";
 
@@ -215,8 +265,8 @@ public class ConfFileHandlerTest {
         Assert.assertEquals(content, stringContent);
     }
 
-     @Test
-     public void testAddConfigurationFile_xmlConfigurationFile_fileAdded() {
+    @Test
+    public void testAddConfigurationFile_xmlConfigurationFile_fileAdded() {
         String fileName = "aaaa." + ConfigurationFileTypes.XML.getFileExtension();
         String content = "content";
 
@@ -232,8 +282,8 @@ public class ConfFileHandlerTest {
         Assert.assertEquals(content, stringContent);
     }
 
-     @Test
-     public void testAddConfigurationFile_yamlConfigurationFile_fileAdded() {
+    @Test
+    public void testAddConfigurationFile_yamlConfigurationFile_fileAdded() {
         String fileName = "aaaa." + ConfigurationFileTypes.YAML.getFileExtension();
         String content = "content";
 
@@ -249,8 +299,8 @@ public class ConfFileHandlerTest {
         Assert.assertEquals(content, stringContent);
     }
 
-     @Test
-     public void testAddConfigurationFile_ymlConfigurationFile_fileAdded() {
+    @Test
+    public void testAddConfigurationFile_ymlConfigurationFile_fileAdded() {
         String fileName = "aaaa." + ConfigurationFileTypes.YML.getFileExtension();
         String content = "content";
 
@@ -266,9 +316,8 @@ public class ConfFileHandlerTest {
         Assert.assertEquals(content, stringContent);
     }
 
-
-     @Test
-     public void testAddConfigurationFile_ccfConfigurationFile_origFileAdded() {
+    @Test
+    public void testAddConfigurationFile_ccfConfigurationFile_origFileAdded() {
         String fileName = "aaaa." + ConfigurationFileTypes.CCF.getFileExtension();
         String content = "content";
 
@@ -284,8 +333,8 @@ public class ConfFileHandlerTest {
         Assert.assertEquals(content, stringContent);
     }
 
-     @Test
-     public void testAddConfigurationFile_cnfConfigurationFile_origFileAdded() {
+    @Test
+    public void testAddConfigurationFile_cnfConfigurationFile_origFileAdded() {
         String fileName = "aaaa." + ConfigurationFileTypes.CNF.getFileExtension();
         String content = "content";
 
@@ -301,8 +350,8 @@ public class ConfFileHandlerTest {
         Assert.assertEquals(content, stringContent);
     }
 
-     @Test
-     public void testAddConfigurationFile_confConfigurationFile_origFileAdded() {
+    @Test
+    public void testAddConfigurationFile_confConfigurationFile_origFileAdded() {
         String fileName = "aaaa." + ConfigurationFileTypes.CONF.getFileExtension();
         String content = "content";
 
@@ -318,8 +367,8 @@ public class ConfFileHandlerTest {
         Assert.assertEquals(content, stringContent);
     }
 
-     @Test
-     public void testAddConfigurationFile_inConfigurationFile_origFileAdded() {
+    @Test
+    public void testAddConfigurationFile_inConfigurationFile_origFileAdded() {
         String fileName = "aaaa." + ConfigurationFileTypes.SH.getFileExtension() + "." + ConfigurationFileTypes.IN.getFileExtension();
         String content = "content";
 
@@ -335,8 +384,8 @@ public class ConfFileHandlerTest {
         Assert.assertEquals(content, stringContent);
     }
 
-     @Test
-     public void testAddConfigurationFile_noExtensionConfigurationFile_origFileAdded() {
+    @Test
+    public void testAddConfigurationFile_noExtensionConfigurationFile_origFileAdded() {
         String fileName = "aaaa." + ConfigurationFileTypes.NO_EXTENSION.getFileExtension();
         String content = "content";
 
@@ -352,8 +401,8 @@ public class ConfFileHandlerTest {
         Assert.assertEquals(content, stringContent);
     }
 
-     @Test
-     public void testAddConfigurationFile_perfmapConfigurationFile_origFileAdded() {
+    @Test
+    public void testAddConfigurationFile_perfmapConfigurationFile_origFileAdded() {
         String fileName = "aaaa." + ConfigurationFileTypes.PERFMAP.getFileExtension();
         String content = "content";
 
@@ -369,8 +418,8 @@ public class ConfFileHandlerTest {
         Assert.assertEquals(content, stringContent);
     }
 
-     @Test
-     public void testAddConfigurationFile_propertyConfigurationFile_origFileAdded() {
+    @Test
+    public void testAddConfigurationFile_propertyConfigurationFile_origFileAdded() {
         String fileName = "aaaa." + ConfigurationFileTypes.PROPERTY.getFileExtension();
         String content = "content";
 
@@ -386,8 +435,8 @@ public class ConfFileHandlerTest {
         Assert.assertEquals(content, stringContent);
     }
 
-     @Test
-     public void testAddConfigurationFile_shConfigurationFile_origFileAdded() {
+    @Test
+    public void testAddConfigurationFile_shConfigurationFile_origFileAdded() {
         String fileName = "aaaa." + ConfigurationFileTypes.SH.getFileExtension();
         String content = "content";
 
@@ -403,8 +452,8 @@ public class ConfFileHandlerTest {
         Assert.assertEquals(content, stringContent);
     }
 
-     @Test
-     public void testAddConfigurationFile_typesConfigurationFile_origFileAdded() {
+    @Test
+    public void testAddConfigurationFile_typesConfigurationFile_origFileAdded() {
         String fileName = "aaaa." + ConfigurationFileTypes.TYPES.getFileExtension();
         String content = "content";
 
@@ -420,8 +469,8 @@ public class ConfFileHandlerTest {
         Assert.assertEquals(content, stringContent);
     }
 
-     @Test
-     public void testAddConfigurationFile_xmlConfigurationFile_origFileAdded() {
+    @Test
+    public void testAddConfigurationFile_xmlConfigurationFile_origFileAdded() {
         String fileName = "aaaa." + ConfigurationFileTypes.XML.getFileExtension();
         String content = "content";
 
@@ -437,8 +486,8 @@ public class ConfFileHandlerTest {
         Assert.assertEquals(content, stringContent);
     }
 
-     @Test
-     public void testAddConfigurationFile_yamlConfigurationFile_origFileAdded() {
+    @Test
+    public void testAddConfigurationFile_yamlConfigurationFile_origFileAdded() {
         String fileName = "aaaa." + ConfigurationFileTypes.YAML.getFileExtension();
         String content = "content";
 
@@ -454,8 +503,8 @@ public class ConfFileHandlerTest {
         Assert.assertEquals(content, stringContent);
     }
 
-     @Test
-     public void testAddConfigurationFile_ymlConfigurationFile_origFileAdded() {
+    @Test
+    public void testAddConfigurationFile_ymlConfigurationFile_origFileAdded() {
         String fileName = "aaaa." + ConfigurationFileTypes.YML.getFileExtension();
         String content = "content";
 
