@@ -51,7 +51,6 @@ package com.openexchange.admin.storage.sqlStorage;
 
 import java.sql.Connection;
 import com.openexchange.admin.rmi.exceptions.PoolException;
-import com.openexchange.database.DatabaseService;
 import com.openexchange.exception.OXException;
 
 public class OXAdminPoolDBPoolExtension extends OXAdminPoolDBPool implements OXAdminPoolInterfaceExtension {
@@ -63,70 +62,56 @@ public class OXAdminPoolDBPoolExtension extends OXAdminPoolDBPool implements OXA
     }
 
     @Override
-    public int getDBPoolIdForContextId(final int contextId) throws PoolException {
-        return new DatabaseServiceCallable<Integer>() {
-
-            @Override
-            protected Integer doPerform(DatabaseService databaseService) throws OXException {
-                return Integer.valueOf(databaseService.getWritablePool(contextId));
-            }
-        }.perform(getService()).intValue();
+    public int getDBPoolIdForContextId(int contextId) throws PoolException {
+        try {
+            return getService().getWritablePool(contextId);
+        } catch (OXException e) {
+            throw new PoolException("" + e.getMessage(), e);
+        }
     }
 
     @Override
-    public Connection getWRITEConnectionForPoolId(final int poolId, final String schema) throws PoolException {
-        return new DatabaseServiceCallable<Connection>() {
-
-            @Override
-            protected Connection doPerform(DatabaseService databaseService) throws OXException {
-                return databaseService.get(poolId, schema);
-            }
-        }.perform(getService());
+    public Connection getWRITEConnectionForPoolId(int poolId, String schema) throws PoolException {
+        try {
+            return getService().get(poolId, schema);
+        } catch (OXException e) {
+            throw new PoolException("" + e.getMessage(), e);
+        }
     }
 
     @Override
-    public void pushWRITEConnectionForPoolId(final int poolId, final Connection con) throws PoolException {
-        new DatabaseServiceCallable<Void>() {
-
-            @Override
-            protected Void doPerform(DatabaseService databaseService) throws OXException {
-                databaseService.back(poolId, con);
-                return null;
-            }
-        }.perform(getService());
+    public void pushWRITEConnectionForPoolId(int poolId, Connection con) {
+        try {
+            getService().back(poolId, con);
+        } catch (PoolException e) {
+            LOG.error("", e);
+        }
     }
 
     @Override
     public Connection getWRITENoTimeoutConnectionForPoolId(final int poolId, final String schema) throws PoolException {
-        return new DatabaseServiceCallable<Connection>() {
-
-            @Override
-            protected Connection doPerform(DatabaseService databaseService) throws OXException {
-                return databaseService.getNoTimeout(poolId, schema);
-            }
-        }.perform(getService());
+        try {
+            return getService().getNoTimeout(poolId, schema);
+        } catch (OXException e) {
+            throw new PoolException("" + e.getMessage(), e);
+        }
     }
 
     @Override
-    public void pushWRITENoTimeoutConnectionForPoolId(final int poolId, final Connection con) throws PoolException {
-        new DatabaseServiceCallable<Void>() {
-
-            @Override
-            protected Void doPerform(DatabaseService databaseService) throws OXException {
-                databaseService.backNoTimeoout(poolId, con);
-                return null;
-            }
-        }.perform(getService());
+    public void pushWRITENoTimeoutConnectionForPoolId(int poolId, Connection con) {
+        try {
+            getService().backNoTimeoout(poolId, con);
+        } catch (PoolException e) {
+            LOG.error("", e);
+        }
     }
 
     @Override
     public String getSchemeForContextId(final int contextId) throws PoolException {
-        return new DatabaseServiceCallable<String>() {
-
-            @Override
-            protected String doPerform(DatabaseService databaseService) throws OXException {
-                return databaseService.getSchemaName(contextId);
-            }
-        }.perform(getService());
+        try {
+            return getService().getSchemaName(contextId);
+        } catch (OXException e) {
+            throw new PoolException("" + e.getMessage(), e);
+        }
     }
 }
