@@ -50,6 +50,7 @@ package com.openexchange.admin.rmi;
 
 import java.rmi.Remote;
 import java.rmi.RemoteException;
+import com.openexchange.exception.OXException;
 
 /**
  *
@@ -80,8 +81,10 @@ public interface OXAdminCoreInterface extends Remote {
     /**
      * This methods checks if all plugins have been loaded successfully
      *
+     * @param credentials The credentials
      * @return true if all plugins are loaded successfully, false if not
      * @throws RemoteException
+     * @throws OXException 
      */
-    public boolean allPluginsLoaded() throws RemoteException;
+    public boolean allPluginsLoaded() throws RemoteException, OXException;
 }
