@@ -50,12 +50,19 @@
 package com.openexchange.admin.storage.sqlStorage;
 
 import java.sql.Connection;
+import org.slf4j.Logger;
 import com.openexchange.admin.rmi.exceptions.PoolException;
 import com.openexchange.database.DatabaseService;
+import com.openexchange.database.SchemaInfo;
 import com.openexchange.exception.OXException;
 
 public class OXAdminPoolDBPoolExtension extends OXAdminPoolDBPool implements OXAdminPoolInterfaceExtension {
 
+    /** Simple class to delay initialization until needed */
+    private static class LoggerHolder {
+        static final Logger LOG = org.slf4j.LoggerFactory.getLogger(OXAdminPoolDBPoolExtension.class);
+    }
+
     public OXAdminPoolDBPoolExtension() {
         super();
     }
@@ -140,4 +147,14 @@ public class OXAdminPoolDBPoolExtension extends OXAdminPoolDBPool implements OXA
         }.perform(getService());
     }
 
+    @Override
+    public SchemaInfo getSchemaInfoForContextId(final int context_id) throws PoolException {
+        return new DatabaseServiceCallable<SchemaInfo>() {
+
+            @Override
+            protected SchemaInfo doPerform(DatabaseService databaseService) throws OXException {
+                return databaseService.getSchemaInfo(context_id);
+            }
+        }.perform(getService());
+    }
 }
