@@ -60,41 +60,40 @@ import com.openexchange.mail.mime.QuotedInternetAddress;
 
 /**
  * @author choeger
- *
  */
 public class GenericChecks {
 
-//    ftp://ftp.rfc-editor.org/in-notes/rfc2822.txt
-//
-//        3.2.4. Atom
-//
-//        atext           =       ALPHA / DIGIT / ; Any character except controls,
-//                                "!" / "#" /     ;  SP, and specials.
-//                                "$" / "%" /     ;  Used for atoms
-//                                "&" / "'" /
-//                                "*" / "+" /
-//                                "-" / "/" /
-//                                "=" / "?" /
-//                                "^" / "_" /
-//                                "`" / "{" /
-//                                "|" / "}" /
-//                                "~"
+    //    ftp://ftp.rfc-editor.org/in-notes/rfc2822.txt
+    //
+    //        3.2.4. Atom
+    //
+    //        atext           =       ALPHA / DIGIT / ; Any character except controls,
+    //                                "!" / "#" /     ;  SP, and specials.
+    //                                "$" / "%" /     ;  Used for atoms
+    //                                "&" / "'" /
+    //                                "*" / "+" /
+    //                                "-" / "/" /
+    //                                "=" / "?" /
+    //                                "^" / "_" /
+    //                                "`" / "{" /
+    //                                "|" / "}" /
+    //                                "~"
     /**
      * This method checks if an address contains invalid characters
      *
      * @param address The address string to check
      */
-    public final static boolean isValidMailAddress(final String address)  {
-        if (null != address) {
-            try {
-                new QuotedInternetAddress(address);
-                return true;
-            } catch (final AddressException e) {
-                return false;
-            }
-            //return address.matches("[$%\\.+a-zA-Z0-9_#$&'/=!?^`{|}~*-]+@[\\.a-zA-Z0-9_-]+");
+    @SuppressWarnings("unused")
+    public final static boolean isValidMailAddress(String address) {
+        if (null == address) {
+            return false;
+        }
+        try {
+            new QuotedInternetAddress(address);
+            return true;
+        } catch (final AddressException e) {
+            return false;
         }
-        return false;
     }
 
     /**
@@ -103,8 +102,8 @@ public class GenericChecks {
      * @param address The address string to check
      * @throws InvalidDataException If given address string is not a valid email address
      */
-    public final static void checkValidMailAddress(final String address) throws InvalidDataException {
-        if (!Strings.isEmpty(address) && !isValidMailAddress(address)) {
+    public final static void checkValidMailAddress(String address) throws InvalidDataException {
+        if (Strings.isNotEmpty(address) && !isValidMailAddress(address)) {
             throw new InvalidDataException("Invalid email address");
         }
     }
@@ -121,9 +120,9 @@ public class GenericChecks {
      * @param user
      * @throws InvalidDataException
      */
-    public final static void checkChangeValidPasswordMech(final PasswordMechObject user) throws InvalidDataException {
+    public final static void checkChangeValidPasswordMech(PasswordMechObject user) throws InvalidDataException {
         checkCreateValidPasswordMech(user);
-        if( user.getPasswordMech() != null && user.getPassword() == null ) {
+        if (user.getPasswordMech() != null && user.getPassword() == null) {
             throw new InvalidDataException("When changing password mechanism, the password string must also be supplied");
         }
     }
@@ -135,13 +134,13 @@ public class GenericChecks {
      * @param user
      * @throws InvalidDataException
      */
-    public final static void checkCreateValidPasswordMech(final PasswordMechObject user) throws InvalidDataException {
+    public final static void checkCreateValidPasswordMech(PasswordMechObject user) throws InvalidDataException {
         final String mech = user.getPasswordMech();
-        if( mech != null ) {
-            if( ! mech.equalsIgnoreCase(PasswordMechObject.CRYPT_MECH) && ! mech.equalsIgnoreCase(PasswordMechObject.SHA_MECH) ) {
-                throw new InvalidDataException("Invalid PasswordMech: " + mech + ", Valid Mechs: " + PasswordMechObject.CRYPT_MECH +
-                        ":" + PasswordMechObject.SHA_MECH);
-            }
+        if (mech == null) {
+            return;
+        }
+        if (!mech.equalsIgnoreCase(PasswordMechObject.CRYPT_MECH) && !mech.equalsIgnoreCase(PasswordMechObject.SHA_MECH)) {
+            throw new InvalidDataException("Invalid PasswordMech: " + mech + ", Valid Mechs: " + PasswordMechObject.CRYPT_MECH + ":" + PasswordMechObject.SHA_MECH);
         }
     }
 
@@ -156,15 +155,19 @@ public class GenericChecks {
      * @throws NoSuchAlgorithmException
      * @throws UnsupportedEncodingException
      */
-    public final static boolean authByMech(final String crypted, final String clear, final String mech) throws NoSuchAlgorithmException, UnsupportedEncodingException {
-        if("{CRYPT}".equals(mech)) {
-            return UnixCrypt.matches(crypted, clear);
-        } else if("{SHA}".equals(mech)) {
-            return SHACrypt.makeSHAPasswd(clear).equals(crypted);
-        } else if("{BCRYPT}".equals(mech)) {
-            return BCrypt.checkpw(clear, crypted);
-        } else {
+    public final static boolean authByMech(String crypted, String clear, String mech) throws NoSuchAlgorithmException, UnsupportedEncodingException {
+        if (mech == null) {
             return false;
         }
+        switch (mech) {
+            case "{CRYPT}":
+                return UnixCrypt.matches(crypted, clear);
+            case "{SHA}":
+                return SHACrypt.makeSHAPasswd(clear).equals(crypted);
+            case "{BCRYPT}":
+                return BCrypt.checkpw(clear, crypted);
+            default:
+                return false;
+        }
     }
 }
