@@ -129,17 +129,13 @@ public class ContextFilestoreDataMover extends FilestoreDataMover {
                 throw new StorageException(e);
             }
 
-            final File fsDirectory = new File(srcFullUri);
+            File fsDirectory = new File(srcFullUri);
             if (fsDirectory.exists()) {
                 ArrayOutput output = new ShellExecutor().executeprocargs(new String[] { "rsync", "-a", fsDirectory.getAbsolutePath(), ensureEndingSlash(dstBaseUri.getPath()).toString() });
                 if (0 != output.exitstatus) {
                     throw new ProgrammErrorException("Wrong exit status. Exit status was: " + output.exitstatus + " Stderr was: \n" + output.errOutput.toString() + '\n' + "and stdout was: \n" + output.stdOutput.toString());
                 }
-                try {
-                    FileUtils.deleteDirectory(fsDirectory);
-                } catch (Exception e) {
-                    LOGGER.error("{} failed to delete source location {}", Thread.currentThread().getName(), fsDirectory.getAbsolutePath(), e);
-                }
+                FileUtils.deleteDirectory(fsDirectory);
 
                 reverter = new Reverter() {
 
@@ -151,11 +147,7 @@ public class ContextFilestoreDataMover extends FilestoreDataMover {
                             if (0 != output.exitstatus) {
                                 throw new ProgrammErrorException("Wrong exit status. Exit status was: " + output.exitstatus + " Stderr was: \n" + output.errOutput.toString() + '\n' + "and stdout was: \n" + output.stdOutput.toString());
                             }
-                            try {
-                                FileUtils.deleteDirectory(dfsDirectory);
-                            } catch (Exception e) {
-                                LOGGER.error("{} failed to delete destination location {}", Thread.currentThread().getName(), fsDirectory.getAbsolutePath(), e);
-                            }
+                            FileUtils.deleteDirectory(dfsDirectory);
                         } catch (Exception e) {
                             LOGGER.error("{} failed to revert directory {}", Thread.currentThread().getName(), dfsDirectory.getAbsolutePath(), e);
                         }
